<?php

namespace App\Http\Controllers;

use App\Events\SendUpdateStatus;
use App\Http\Actions\Payment\CheckPaymentAction;
use App\Http\Actions\Payment\CreatePaymentAction;
use App\Http\Requests\CreatePaymentRequest;
use App\Http\Resources\CreatePaymentResource;
use App\Models\Payment;
use Illuminate\Http\Request;

class PaymentController extends Controller
{
    public function create(CreatePaymentRequest $request, CreatePaymentAction $action)
    {
        $payment = $action->execute($request->integer('amount'));
        return response()->json(new CreatePaymentResource($payment));
    }

    public function check(Payment $payment, CheckPaymentAction $action)
    {
        $payment = $action->execute($payment);
        return ['status' => $payment->status];
    }

    public function total()
    {
        return [
            'total' => Payment::select('amount')->where('status', 'PAID')->sum('amount')
        ];
    }

    public function callback($payment_id, Request $request)
    {
        $payment = Payment::where('payment_id', $payment_id)->first();

        if($payment){
            $payment->update(['status' => $request->status]);
            broadcast(new SendUpdateStatus($payment));
        }

        return response(['message' => 'Message Received Successfully'], 202);
    }
}
